@@ -49,9 +49,9 @@ public:
     };
 
     enum OrgType {
-        Distribution, //!< distribution itself
-        Distributor, //!< distributer of the current distribution
-        Manufacturer //!< manufacturer of the current distribution or device
+        Distribution, //!<@~english distribution itself
+        Distributor, //!<@~english distributer of the current distribution
+        Manufacturer //!<@~english manufacturer of the current distribution or device
     };
 
     enum UosType {
@@ -138,9 +138,9 @@ public:
     static QString deepinCopyright();
 
     // uos version interface
-    Q_DECL_DEPRECATED_X("Use arch() instead") static UosType uosType();
+    static UosType uosType();
     static UosEdition uosEditionType();
-    static UosArch uosArch();
+    Q_DECL_DEPRECATED_X("Use arch() instead") static UosArch uosArch();
     static QString uosProductTypeName(const QLocale &locale = QLocale::system());
     static QString uosSystemName(const QLocale &locale = QLocale::system());
     static QString uosEditionName(const QLocale &locale = QLocale::system());
