@@ -46,7 +46,7 @@ public:
     void ensureReleaseInfo();
     void ensureComputerInfo();
     QMap<QString, QString> parseInfoFile(QFile &file);
-
+    QMap<QString, QString> parseInfoContent(const QString &content);
 #ifdef Q_OS_LINUX
     DSysInfo::DeepinType deepinType = DSysInfo::DeepinType(-1);
     QMap<QString, QString> deepinTypeMap; //Type Name with Language
@@ -511,6 +511,21 @@ QMap<QString, QString> DSysInfoPrivate::parseInfoFile(QFile &file)
     return map;
 }
 
+QMap<QString, QString> DSysInfoPrivate::parseInfoContent(const QString &content)
+{
+    QMap<QString, QString> map;
+    QStringList lineContents = content.split("\n");
+    for (auto lineContent : lineContents) {
+        if (lineContent.contains(':')) {
+            QStringList list = lineContent.split(':');
+            if (list.size() == 2) {
+                map.insert(list.first().trimmed(), list.back().trimmed());
+            }
+        }
+    }
+    return map;
+}
+
 Q_GLOBAL_STATIC(DSysInfoPrivate, siGlobal)
 
 QString DSysInfo::operatingSystemName()
@@ -534,6 +549,10 @@ bool DSysInfo::isDeepin()
 
 bool DSysInfo::isDDE()
 {
+    if (!DSysInfo::isDeepin()) {
+        return qgetenv("XDG_SESSION_DESKTOP") == "deepin";
+    }
+
     siGlobal->ensureDeepinInfo();
 
     return siGlobal->deepinType != UnknownDeepin;
@@ -582,6 +601,8 @@ QString DSysInfo::deepinCopyright()
  */
 DSysInfo::UosType DSysInfo::uosType()
 {
+    if (!DSysInfo::isDeepin())
+        return UosTypeUnknown;
     siGlobal->ensureOsVersion();
 
     UosType ost = UosTypeUnknown;
@@ -995,6 +1016,9 @@ QString DSysInfo::computerName()
 
 QString DSysInfo::cpuModelName()
 {
+    if (!siGlobal->cpuModelName.isEmpty())
+        return siGlobal->cpuModelName;
+
 #ifdef Q_OS_LINUX
     static QFile file("/proc/cpuinfo");
 
@@ -1009,10 +1033,31 @@ QString DSysInfo::cpuModelName()
         } else if (map.contains("cpu model")) {
             // loonson3-cpuinfo sw-cpuinfo
             siGlobal->cpuModelName = map.value("cpu model");
+        } else if (map.contains("Hardware")) {
+            // "HardWare" field contains cpu info on huawei kirin machine (e.g. klv or klu)
+            siGlobal->cpuModelName = map.value("Hardware");
         }
 
         file.close();
     }
+
+    // Get the cpu info by executing lscpu command
+    if (siGlobal->cpuModelName.isEmpty()) {
+        QProcess lscpu;
+        QStringList env = QProcess::systemEnvironment();
+        env << "LC_ALL=C"; // Add an environment variable
+        lscpu.setEnvironment(env);
+        lscpu.start("/usr/bin/lscpu");
+        if (lscpu.waitForFinished(3000)) {
+            const QMap<QString, QString> map = siGlobal->parseInfoContent(lscpu.readAll());
+            if (map.contains("Model name")) {
+                siGlobal->cpuModelName = map.value("Model name");
+            }
+        } else {
+            qWarning() << "lscpu:" << lscpu.errorString();
+        }
+    }
+
     return siGlobal->cpuModelName;
 #endif
     return QString();
@@ -1068,10 +1113,10 @@ qint64 DSysInfo::systemDiskSize()
 {
 #ifdef Q_OS_LINUX
     // Getting Disk Size
-    const QString &deviceName = QStorageInfo::root().device();
+    QString deviceName;
     QProcess lsblk;
 
-    lsblk.start("lsblk", {"-Jlpb", "-oNAME,KNAME,PKNAME,SIZE"}, QIODevice::ReadOnly);
+    lsblk.start("lsblk", {"-Jlpb", "-oNAME,KNAME,PKNAME,SIZE,MOUNTPOINT"}, QIODevice::ReadOnly);
 
     if (!lsblk.waitForFinished()) {
         return -1;
@@ -1091,6 +1136,11 @@ qint64 DSysInfo::systemDiskSize()
             QString kname = oneValue.toObject().value("kname").toString();
             QString pkname = oneValue.toObject().value("pkname").toString();
             qulonglong size = oneValue.toObject().value("size").toVariant().toULongLong();
+            QString deviceNameMP = oneValue.toObject().value("mountpoint").toString();
+
+            if ("/" ==  deviceNameMP){
+                deviceName = name;
+            }
 
             if (keyName.isNull() && deviceName == name) {
                 keyName = kname;
