@@ -19,17 +19,19 @@
 DCORE_BEGIN_NAMESPACE
 
 /*!
+@~english
   \headerfile <Logger.h>
   \inmodule dtkcore
-  \brief A file containing the description of Logger class and and additional useful macros for logging.
+  @brief A file containing the description of Logger class and and additional useful macros for logging.
  */
 
 /*!
+@~english
   \macro Dtk::Core::logger
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::logger
 
-  \brief Macro returning the current instance of Logger object
+  @brief Macro returning the current instance of Logger object
 
   If you haven't created a local Logger object it returns the same value as the Logger::globalInstance() functions.
   This macro is a recommended way to get an access to the Logger instance used in current class.
@@ -40,201 +42,214 @@ DCORE_BEGIN_NAMESPACE
   logger->registerAppender(consoleAppender);
   \endcode
 
-  \sa Dtk::Core::Logger::globalInstance()
+  @sa Dtk::Core::Logger::globalInstance()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dTrace
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dTrace
 
-  \brief Writes the trace log record
+  @brief Writes the trace log record
 
   This macro is the convenient way to call Logger::write(). It uses the common preprocessor macros \c __FILE__,
   \c __LINE__ and the standard Qt \c Q_FUNC_INFO macros to automatically determine the needed parameters to call
   Logger::write().
 
-  \note This and other (dInfo() etc...) macros uses the variadic macro arguments to give convenient usage form for
+  @note This and other (dInfo() etc...) macros uses the variadic macro arguments to give convenient usage form for
   the different versions of Logger::write() (using the QString or const char *argument or returning the QDebug class
   instance). Not all compilers will support this. Please, consider reviewing your compiler documentation to ensure
   it support __VA_ARGS__ macro.
 
-  \sa Dtk::Core::dInfo Dtk::Core::dDebug Dtk::Core::dWarning Dtk::Core::dError
-  \sa Dtk::Core::Logger::LogLevel
-  \sa Dtk::Core::Logger::write()
+  @sa Dtk::Core::dInfo Dtk::Core::dDebug Dtk::Core::dWarning Dtk::Core::dError
+  @sa Dtk::Core::Logger::LogLevel
+  @sa Dtk::Core::Logger::write()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dDebug
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dDebug
 
-  \brief Writes the debug log record
+  @brief Writes the debug log record
 
   This macro records the debug log record using the Logger::write() function. It works similar to the dTrace()
   macro.
 
-  \sa Dtk::Core::dTrace Dtk::Core::dInfo Dtk::Core::dWarning Dtk::Core::dError
-  \sa Dtk::Core::Logger::LogLevel
-  \sa Dtk::Core::Logger::write()
+  @sa Dtk::Core::dTrace Dtk::Core::dInfo Dtk::Core::dWarning Dtk::Core::dError
+  @sa Dtk::Core::Logger::LogLevel
+  @sa Dtk::Core::Logger::write()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dInfo
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dInfo
 
-  \brief Writes the info log record
+  @brief Writes the info log record
 
   This macro records the info log record using the Logger::write() function. It works similar to the dTrace()
   macro.
 
-  \sa Dtk::Core::dTrace Dtk::Core::dDebug Dtk::Core::dWarning Dtk::Core::dError
-  \sa Dtk::Core::Logger::LogLevel
-  \sa Dtk::Core::Logger::write()
+  @sa Dtk::Core::dTrace Dtk::Core::dDebug Dtk::Core::dWarning Dtk::Core::dError
+  @sa Dtk::Core::Logger::LogLevel
+  @sa Dtk::Core::Logger::write()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dWarning
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dWarning
 
-  \brief Write the warning log record
+  @brief Write the warning log record
 
   This macro records the warning log record using the Logger::write() function. It works similar to the dTrace()
   macro.
 
-  \sa Dtk::Core::dTrace Dtk::Core::dInfo Dtk::Core::dDebug Dtk::Core::dError
-  \sa Dtk::Core::Logger::LogLevel
-  \sa Dtk::Core::Logger::write()
+  @sa Dtk::Core::dTrace Dtk::Core::dInfo Dtk::Core::dDebug Dtk::Core::dError
+  @sa Dtk::Core::Logger::LogLevel
+  @sa Dtk::Core::Logger::write()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dError
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dError
 
-  \brief Write the error log record
+  @brief Write the error log record
   This macro records the error log record using the Logger::write() function. It works similar to the dTrace()
   macro.
 
-  \sa Dtk::Core::dTrace
-  \sa Dtk::Core::Logger::LogLevel
-  \sa Dtk::Core::Logger::write()
+  @sa Dtk::Core::dTrace
+  @sa Dtk::Core::Logger::LogLevel
+  @sa Dtk::Core::Logger::write()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dFatal
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dFatal
 
-  \brief Write the fatal log record
+  @brief Write the fatal log record
 
   This macro records the fatal log record using the Logger::write() function. It works similar to the dTrace()
   macro.
 
-  \note Recording of the log record using the Logger::Fatal log level will lead to calling the STL abort()
+  @note Recording of the log record using the Logger::Fatal log level will lead to calling the STL abort()
         function, which will interrupt the running of your software and begin the writing of the core dump.
 
-  \sa Dtk::Core::dTrace
-  \sa Dtk::Core::Logger::LogLevel
-  \sa Dtk::Core::Logger::write()
+  @sa Dtk::Core::dTrace
+  @sa Dtk::Core::Logger::LogLevel
+  @sa Dtk::Core::Logger::write()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dCTrace(category)
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dCTrace()
 
-  \brief Writes the trace log record to the specific category
+  @brief Writes the trace log record to the specific category
 
   This macro is the similar to the dTrace() macro, but has a category parameter
   to write only to the category appenders (registered using Logger::registerCategoryAppender() method).
 
-  \a category category name string
+  @param[in] category category name string
 
-  \sa Dtk::Core::dTrace
-  \sa Dtk::Core::Logger::LogLevel
-  \sa Dtk::Core::Logger::registerCategoryAppender()
-  \sa Dtk::Core::Logger::write()
-  \sa Dtk::Core::dCategory(), Dtk::Core::dGlobalCategory()
+  @sa Dtk::Core::dTrace
+  @sa Dtk::Core::Logger::LogLevel
+  @sa Dtk::Core::Logger::registerCategoryAppender()
+  @sa Dtk::Core::Logger::write()
+  @sa Dtk::Core::dCategory(), Dtk::Core::dGlobalCategory()
  */
 
 
 /*!
+@~english
   \macro Dtk::Core::dCDebug
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dCDebug
 
-  \brief Writes the debug log record to the specific category
+  @brief Writes the debug log record to the specific category
 
   This macro records the debug log record using the Logger::write() function. It works similar to the dCTrace()
   macro.
 
-  \sa Dtk::Core::dCTrace()
+  @sa Dtk::Core::dCTrace()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dCInfo
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dCInfo
 
-  \brief Writes the info log record to the specific category
+  @brief Writes the info log record to the specific category
 
   This macro records the info log record using the Logger::write() function. It works similar to the dCTrace()
   macro.
 
-  \sa Dtk::Core::dCTrace()
+  @sa Dtk::Core::dCTrace()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dCWarning
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dCWarning
 
-  \brief Writes the warning log record to the specific category
+  @brief Writes the warning log record to the specific category
 
   This macro records the warning log record using the Logger::write() function. It works similar to the dCTrace()
   macro.
 
-  \sa Dtk::Core::dCTrace()
+  @sa Dtk::Core::dCTrace()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dCError
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dCError
 
-  \brief Writes the error log record to the specific category
+  @brief Writes the error log record to the specific category
 
   This macro records the error log record using the Logger::write() function. It works similar to the dCTrace()
   macro.
 
-  \sa Dtk::Core::dCTrace()
+  @sa Dtk::Core::dCTrace()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dCFatal
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dCFatal
 
-  \brief Write the fatal log record to the specific category
+  @brief Write the fatal log record to the specific category
 
   This macro records the fatal log record using the Logger::write() function. It works similar to the dCTrace()
   macro.
 
-  \note Recording of the log record using the Logger::Fatal log level will lead to calling the STL abort()
+  @note Recording of the log record using the Logger::Fatal log level will lead to calling the STL abort()
         function, which will interrupt the running of your software and begin the writing of the core dump.
 
-  \sa Dtk::Core::dCTrace()
+  @sa Dtk::Core::dCTrace()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dCategory(category)
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dCategory()
 
-  \brief Create logger instance inside your custom class to log all messages to the specified \a category
+  @brief Create logger instance inside your custom class to log all messages to the specified \a category
 
   This macro is used to pass all log messages inside your custom class to the specific \a category.
   You must include this macro inside your class declaration (similarly to the Q_OBJECT macro).
@@ -244,7 +259,7 @@ DCORE_BEGIN_NAMESPACE
   Thus, any call to loggerInstance() (for example, inside dTrace() macro) will return the local Logger object,
   so any logging message will be directed to the default category.
 
-  \note This macro does not register any appender to the newly created logger instance. You should register
+  @note This macro does not register any appender to the newly created logger instance. You should register
   logger appenders manually, inside your class.
 
   Usage example:
@@ -263,18 +278,19 @@ DCORE_BEGIN_NAMESPACE
   }
   \endcode
 
-  \sa Dtk::Core::Logger::write()
-  \sa Dtk::Core::dTrace()
-  \sa Dtk::Core::Logger::registerCategoryAppender()
-  \sa Dtk::Core::Logger::setDefaultCategory()
+  @sa Dtk::Core::Logger::write()
+  @sa Dtk::Core::dTrace()
+  @sa Dtk::Core::Logger::registerCategoryAppender()
+  @sa Dtk::Core::Logger::setDefaultCategory()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dGlobalCategory(category)
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dGlobalCategory()
 
-  \brief Create logger instance inside your custom class to log all messages both to the specified \a category and to
+  @brief Create logger instance inside your custom class to log all messages both to the specified \a category and to
   the global logger instance.
 
   This macro is similar to dCategory(), but also passes all log messages to the global logger instance appenders.
@@ -283,19 +299,20 @@ DCORE_BEGIN_NAMESPACE
   logger->logToGlobalInstance(logger->defaultCategory(), true);
   \endcode
 
-  \sa Dtk::Core::dCategory
-  \sa Dtk::Core::Logger::logToGlobalInstance()
-  \sa Dtk::Core::Logger::defaultCategory()
-  \sa Dtk::Core::Logger::registerCategoryAppender()
-  \sa Dtk::Core::Logger::write()
+  @sa Dtk::Core::dCategory
+  @sa Dtk::Core::Logger::logToGlobalInstance()
+  @sa Dtk::Core::Logger::defaultCategory()
+  @sa Dtk::Core::Logger::registerCategoryAppender()
+  @sa Dtk::Core::Logger::write()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dAssert
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dAssert
 
-  \brief Check the assertion
+  @brief Check the assertion
 
   This macro is a convenient and recommended to use way to call Logger::writeAssert() function. It uses the
   preprocessor macros (as the dDebug() does) to fill the necessary arguments of the Logger::writeAssert() call. It
@@ -309,15 +326,16 @@ DCORE_BEGIN_NAMESPACE
   dAssert(b == true);
   \endcode
 
-  \sa Dtk::Core::Logger::writeAssert()
+  @sa Dtk::Core::Logger::writeAssert()
  */
 
 /*!
+@~english
   \macro Dtk::Core::dTraceTime
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dTraceTime
 
-  \brief Logs the processing time of current function / code block
+  @brief Logs the processing time of current function / code block
 
   This macro automagically measures the function or code of block execution time and outputs it as a Logger::Trace
   level log record.
@@ -351,8 +369,8 @@ DCORE_BEGIN_NAMESPACE
   // Function bar finished in <time2> ms.
   \endcode
 
-  \note Macro switches to logging the seconds instead of milliseconds when the execution time reaches 10000 ms.
-  \sa Dtk::Core::dDebugTime, Dtk::Core::dInfoTime
+  @note Macro switches to logging the seconds instead of milliseconds when the execution time reaches 10000 ms.
+  @sa Dtk::Core::dDebugTime, Dtk::Core::dInfoTime
  */
 
 /*!
@@ -360,28 +378,30 @@ DCORE_BEGIN_NAMESPACE
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dDebugTime
 
-  \brief Logs the processing time of current function / code block
+  @brief Logs the processing time of current function / code block
 
   This macro automagically measures the function or code of block execution time and outputs it as a Logger::Debug
   level log record. It works similar to dTraceTime() macro.
 
-  \sa Dtk::Core::dTraceTime
+  @sa Dtk::Core::dTraceTime
  */
 
 /*!
+@~english
   \macro Dtk::Core::dInfoTime
   \relates Dtk::Core::Logger
   \keyword Dtk::Core::dInfoTime
 
-  \brief Logs the processing time of current function / code block
+  @brief Logs the processing time of current function / code block
 
   This macro automagically measures the function or code of block execution time and outputs it as a Logger::Info
   level log record. It works similar to dTraceTime() macro.
 
-  \sa Dtk::Core::dTraceTime
+  @sa Dtk::Core::dTraceTime
  */
 
 /*!
+@~english
  \enum Dtk::Core::Logger::LogLevel
  \value Trace
  Can be used for mostly unneeded records used for internal code tracing.
@@ -398,18 +418,19 @@ DCORE_BEGIN_NAMESPACE
 */
 
 /*!
+@~english
   \class Dtk::Core::Logger
   \inmodule dtkcore
 
-  \brief Very simple but rather powerful component which may be used for logging your application activities.
+  @brief Very simple but rather powerful component which may be used for logging your application activities.
 
   Global logger instance created on a first access to it (e.g. registering appenders, calling a dDebug() macro
   etc.) registers itself as a Qt default message handler and captures all the qDebug/dWarning/qCritical output.
 
-  \note Qt 4 qDebug set of macro doesn't support capturing source function name, file name or line number so we
+  @note Qt 4 qDebug set of macro doesn't support capturing source function name, file name or line number so we
         recommend to use dDebug() and other Logger macros instead.
 
-  \sa Dtk::Core::logger
+  @sa Dtk::Core::logger
  */
 
 class LogDevice : public QIODevice
@@ -473,6 +494,7 @@ private:
 //#endif
 
 /*!
+@~english
   \internal
 
   LoggerPrivate class implements the Singleton pattern in a thread-safe way. It contains a static pointer to the
@@ -559,7 +581,8 @@ static void qtLoggerMessageHandler(QtMsgType type, const char *msg)
 
 
 /*!
-  \brief Construct the instance of Logger.
+@~english
+  @brief Construct the instance of Logger.
 
   If you're only using one global instance of logger you wouldn't probably need to use this constructor manually.
   Consider using [logger](@ref logger) macro instead to access the logger instance
@@ -572,13 +595,14 @@ Logger::Logger()
 }
 
 /*!
-  \brief Construct the instance of Logger and set logger default category.
+@~english
+  @brief Construct the instance of Logger and set logger default category.
 
   If you're only using one global instance of logger you wouldn't probably need to use this constructor manually.
   Consider using logger macro instead to access the logger instance and call setDefaultCategory method.
 
-  \sa Logger()
-  \sa setDefaultCategory()
+  @sa Logger()
+  @sa setDefaultCategory()
  */
 Logger::Logger(const QString &defaultCategory)
     :Logger()
@@ -587,7 +611,8 @@ Logger::Logger(const QString &defaultCategory)
 }
 
 /*!
-  \brief Destroy the instance of Logger.
+@~english
+  @brief Destroy the instance of Logger.
 
   You probably wouldn't need to use this function directly. Global instance of logger will be destroyed automatically
   at the end of your QCoreApplication execution
@@ -609,11 +634,12 @@ Logger::~Logger()
 }
 
 /*!
-  \brief Returns the global instance of Logger.
+@~english
+  @brief Returns the global instance of Logger.
 
   In a most cases you shouldn't use this function directly. Consider using [logger](@ref logger) macro instead.
 
-  \sa Dtk::Core::logger
+  @sa Dtk::Core::logger
  */
 Logger *Logger::globalInstance()
 {
@@ -641,12 +667,13 @@ Logger *Logger::globalInstance()
 }
 
 /*!
-  \brief Converts the LogLevel enum value to its string representation.
+@~english
+  @brief Converts the LogLevel enum value to its string representation.
 
   \a logLevel Log level to convert
 
-  \sa LogLevel
-  \sa levelFromString()
+  @sa LogLevel
+  @sa levelFromString()
  */
 QString Logger::levelToString(Logger::LogLevel level)
 {
@@ -670,15 +697,16 @@ QString Logger::levelToString(Logger::LogLevel level)
 }
 
 /*!
-  \brief Converts the LogLevel string representation to enum value.
+@~english
+  @brief Converts the LogLevel string representation to enum value.
 
   Comparation of the strings is case independent. If the log level string provided cannot be understood
   Logger::Debug is returned.
 
   \a s String to be decoded
 
-  \sa LogLevel
-  \sa levelToString()
+  @sa LogLevel
+  @sa levelToString()
  */
 Logger::LogLevel Logger::levelFromString(const QString &str)
 {
@@ -703,7 +731,8 @@ Logger::LogLevel Logger::levelFromString(const QString &str)
 }
 
 /*!
-  \brief Registers the appender to write the log records to.
+@~english
+  @brief Registers the appender to write the log records to.
 
   On the log writing call (using one of the macros or the write() function) Logger traverses through the list of
   the appenders and writes a log records to the each of them. Please, look through the AbstractAppender
@@ -713,11 +742,11 @@ Logger::LogLevel Logger::levelFromString(const QString &str)
 
   \a appender Appender to register in the Logger
 
-  \note Logger takes ownership on the appender and it will delete it on the application exit. According to this,
+  @note Logger takes ownership on the appender and it will delete it on the application exit. According to this,
         appenders must be created on heap to prevent double destruction of the appender.
 
-  \sa registerCategoryAppender
-  \sa AbstractAppender
+  @sa registerCategoryAppender
+  @sa AbstractAppender
  */
 void Logger::registerAppender(AbstractAppender *appender)
 {
@@ -731,7 +760,8 @@ void Logger::registerAppender(AbstractAppender *appender)
 }
 
 /*!
-  \brief Registers the appender to write the log records to the specific category.
+@~english
+  @brief Registers the appender to write the log records to the specific category.
 
   Calling this method, you can link some appender with the named category.
   On the log writing call to the specific category (calling write() with category parameter directly,
@@ -743,17 +773,17 @@ void Logger::registerAppender(AbstractAppender *appender)
   If no category appenders with specific name was registered to the Logger,
   it falls back to logging into the \c std::cerr STL stream, both with simple warning message.
 
-  \a category Category name
-  \a appender Appender to register in the Logger
+  @param[in] category Category name
+  @param[in] appender Appender to register in the Logger
 
-  \note Logger takes ownership on the appender and it will delete it on the application exit. According to this,
+  @note Logger takes ownership on the appender and it will delete it on the application exit. According to this,
         appenders must be created on heap to prevent double destruction of the appender.
 
-  \sa registerAppender
-  \sa Dtk::Core::dCTrace(), Dtk::Core::dCDebug(), Dtk::Core::dCInfo(), Dtk::Core::dCWarning(), Dtk::Core::dCError(), Dtk::Core::dCFatal()
-  \sa Dtk::Core::dCategory(), Dtk::Core::dGlobalCategory()
-  \sa logToGlobalInstance()
-  \sa setDefaultCategory()
+  @sa registerAppender
+  @sa Dtk::Core::dCTrace(), Dtk::Core::dCDebug(), Dtk::Core::dCInfo(), Dtk::Core::dCWarning(), Dtk::Core::dCError(), Dtk::Core::dCFatal()
+  @sa Dtk::Core::dCategory(), Dtk::Core::dGlobalCategory()
+  @sa logToGlobalInstance()
+  @sa setDefaultCategory()
  */
 void Logger::registerCategoryAppender(const QString &category, AbstractAppender *appender)
 {
@@ -768,7 +798,8 @@ void Logger::registerCategoryAppender(const QString &category, AbstractAppender
 }
 
 /*!
-  \brief Links some logging category with the global logger instance appenders.
+@~english
+  @brief Links some logging category with the global logger instance appenders.
 
   If set to true, all log messages to the specified category appenders will also be written to the global logger instance appenders,
   registered using registerAppender().
@@ -776,12 +807,12 @@ void Logger::registerCategoryAppender(const QString &category, AbstractAppender
   By default, all messages to the specific category are written only to the specific category appenders
   (registered using registerCategoryAppender()).
 
-  \a category Category name
-  \a logToGlobal Link or onlink the category from global logger instance appender
+  @param category Category name
+  @param logToGlobal Link or onlink the category from global logger instance appender
 
-  \sa globalInstance
-  \sa registerAppender
-  \sa registerCategoryAppender
+  @sa globalInstance
+  @sa registerAppender
+  @sa registerCategoryAppender
  */
 void Logger::logToGlobalInstance(const QString &category, bool logToGlobal)
 {
@@ -795,7 +826,8 @@ void Logger::logToGlobalInstance(const QString &category, bool logToGlobal)
 }
 
 /*!
-  \brief Sets default logging category.
+@~english
+  @brief Sets default logging category.
 
   All log messages to this category appenders will also be written to general logger instance appenders (registered
   using [registerAppender](@ref registerAppender) method), and vice versa.
@@ -804,14 +836,14 @@ void Logger::logToGlobalInstance(const QString &category, bool logToGlobal)
 
   To unset the default category, pass a null string as a parameter.
 
-  \a category Category name
+  @param[in] category Category name
 
-  \note "category" format marker will be set to the category name for all of these messages
+  @note "category" format marker will be set to the category name for all of these messages
   (see [AbstractStringAppender::setFormat](@ref AbstractStringAppender::setFormat)).
 
-  \sa defaultCategory()
-  \sa registerCategoryAppender()
-  \sa logToGlobalInstance()
+  @sa defaultCategory()
+  @sa registerCategoryAppender()
+  @sa logToGlobalInstance()
  */
 void Logger::setDefaultCategory(const QString &category)
 {
@@ -820,9 +852,10 @@ void Logger::setDefaultCategory(const QString &category)
     d->defaultCategory = category;
 }
 
-//! Returns default logging category name
 /*!
-  \sa setDefaultCategory
+@~english
+  @sa setDefaultCategory
+  @brief Returns default logging category name
  */
 QString Logger::defaultCategory() const
 {
@@ -832,28 +865,29 @@ QString Logger::defaultCategory() const
 }
 
 /*!
-  \brief Writes the log record.
+@~english
+  @brief Writes the log record.
 
   Writes the log records with the supplied arguments to all the registered appenders.
 
-  \note It is not recommended to call this function directly. Instead of this you can just call one of the macros
+  @note It is not recommended to call this function directly. Instead of this you can just call one of the macros
         (dTrace, dTrac, dInfo, dWarning, dError, dFatal) that will supply all the needed
         information to this function.
 
-  \a time - the time stamp of the record
-  \a logLevel - the log level of the record
-  \a file - the name of the source file that requested the log record
-  \a line - the line of the code of source file that requested the log record
-  \a function - name of the function that requested the log record
-  \a category - logging category (0 for default category)
-  \a message - log message
+  @param[in] time - the time stamp of the record
+  @param[in] logLevel - the log level of the record
+  @param[in] file - the name of the source file that requested the log record
+  @param[in] line - the line of the code of source file that requested the log record
+  @param[in] function - name of the function that requested the log record
+  @param[in] category - logging category (0 for default category)
+  @param[in] message - log message
 
-  \note Recording of the log record using the Logger::Fatal log level will lead to calling the STL abort()
+  @note Recording of the log record using the Logger::Fatal log level will lead to calling the STL abort()
         function, which will interrupt the running of your software and begin the writing of the core dump.
 
-  \sa LogLevel
-  \sa Dtk::Core::dTrace(), Dtk::Core::dDebug(), Dtk::Core::dInfo(), Dtk::Core::dWarning(), Dtk::Core::dError(), Dtk::Core::dFatal()
-  \sa AbstractAppender
+  @sa LogLevel
+  @sa Dtk::Core::dTrace(), Dtk::Core::dDebug(), Dtk::Core::dInfo(), Dtk::Core::dWarning(), Dtk::Core::dError(), Dtk::Core::dFatal()
+  @sa AbstractAppender
  */
 void Logger::write(const QDateTime &time, Logger::LogLevel level, const char *file, int line,
                    const char *func, const char *category, const QString &msg)
@@ -862,11 +896,12 @@ void Logger::write(const QDateTime &time, Logger::LogLevel level, const char *fi
 }
 
 /*!
+@~english
   This is the overloaded function provided for the convenience. It behaves similar to the above function.
 
-  This function uses the current timestamp obtained with \c QDateTime::currentDateTime().
+  This function uses the current timestamp obtained with @sa QDateTime::currentDateTime().
 
-  \sa write()
+  @sa write()
  */
 void Logger::write(Logger::LogLevel level, const char *file, int line,
                    const char *func, const char *category, const QString &msg)
@@ -875,6 +910,7 @@ void Logger::write(Logger::LogLevel level, const char *file, int line,
 }
 
 /*!
+@~english
   This is the overloaded function provided for the convenience. It behaves similar to the above function.
 
   This function doesn't accept any log message as argument. It returns the \c QDebug object that can be written
@@ -890,10 +926,10 @@ void Logger::write(Logger::LogLevel level, const char *file, int line,
 
   Please consider reading the Qt Reference Documentation for the description of the QDebug class usage syntax.
 
-  \note This overload is definitely more pleasant to use than the first write() overload, but it behaves definitely
+  @note This overload is definitely more pleasant to use than the first write() overload, but it behaves definitely
         slower than all the above overloads.
 
-  \sa write()
+  @sa write()
  */
 QDebug Logger::write(Logger::LogLevel level, const char *file, int line,
                      const char *func, const char *category)
@@ -905,7 +941,8 @@ QDebug Logger::write(Logger::LogLevel level, const char *file, int line,
 }
 
 /*!
-  \brief Writes the assertion.
+@~english
+  @brief Writes the assertion.
 
   This function writes the assertion record using the write() function.
 
@@ -915,14 +952,14 @@ QDebug Logger::write(Logger::LogLevel level, const char *file, int line,
   The message written to the appenders will be identical to the \a condition argument prefixed with the
   <tt>ASSERT:</tt> notification.
 
-  The \a file parameter is the current file name.
-  The \a line parameter indicates the number of lines to output.
-  The \a func parameter indicates the function name to output.
+  The @param[in] file parameter is the current file name.
+  The @param[in] line parameter indicates the number of lines to output.
+  The @param[in] func parameter indicates the function name to output.
 
-  \note It is not recommended to call this function directly. Instead of this you can just call the LOG_ASSERT
+  @note It is not recommended to call this function directly. Instead of this you can just call the LOG_ASSERT
         macro that will supply all the needed information to this function.
 
-  \sa write()
+  @sa write()
  */
 void Logger::writeAssert(const char *file, int line,
                          const char *func, const char *condition)
