@@ -6,8 +6,8 @@
 
 #include <DDBusExtendedAbstractInterface>
 
-#include <QtDBus/QDBusMetaType>
 #include <QtDBus/QDBusMessage>
+#include <QtDBus/QDBusMetaType>
 #include <QtDBus/QDBusPendingCall>
 #include <QtDBus/QDBusPendingCallWatcher>
 #include <QtDBus/QDBusPendingReply>
@@ -15,6 +15,7 @@
 #include <QtCore/QDebug>
 #include <QtCore/QMetaProperty>
 
+DCORE_BEGIN_NAMESPACE
 
 Q_GLOBAL_STATIC_WITH_ARGS(QByteArray, dBusInterface, ("org.freedesktop.DBus"))
 Q_GLOBAL_STATIC_WITH_ARGS(QByteArray, dBusPropertiesInterface, ("org.freedesktop.DBus.Properties"))
@@ -22,33 +23,36 @@ Q_GLOBAL_STATIC_WITH_ARGS(QByteArray, dBusPropertiesChangedSignal, ("PropertiesC
 Q_GLOBAL_STATIC_WITH_ARGS(QByteArray, propertyChangedSignature, ("propertyChanged(QString,QVariant)"))
 Q_GLOBAL_STATIC_WITH_ARGS(QByteArray, propertyInvalidatedSignature, ("propertyInvalidated(QString)"))
 
-
-DDBusExtendedAbstractInterface::DDBusExtendedAbstractInterface(const QString &service, const QString &path, const char *interface, const QDBusConnection &connection, QObject *parent)
+DDBusExtendedAbstractInterface::DDBusExtendedAbstractInterface(
+    const QString &service, const QString &path, const char *interface, const QDBusConnection &connection, QObject *parent)
     : QDBusAbstractInterface(service, path, interface, connection, parent)
     , m_sync(true)
     , m_useCache(false)
     , m_getAllPendingCallWatcher(0)
     , m_propertiesChangedConnected(false)
 {
-    const_cast<QDBusConnection&>(connection).connect(QString("org.freedesktop.DBus"), QString("/org/freedesktop/DBus"), QString("org.freedesktop.DBus"), QString("NameOwnerChanged"), this, SLOT(onDBusNameOwnerChanged(QString,QString,QString)));
+    const_cast<QDBusConnection &>(connection)
+        .connect(QString("org.freedesktop.DBus"),
+                 QString("/org/freedesktop/DBus"),
+                 QString("org.freedesktop.DBus"),
+                 QString("NameOwnerChanged"),
+                 this,
+                 SLOT(onDBusNameOwnerChanged(QString, QString, QString)));
 }
 
-DDBusExtendedAbstractInterface::~DDBusExtendedAbstractInterface()
+DDBusExtendedAbstractInterface::~DDBusExtendedAbstractInterface() {}
+
+void DDBusExtendedAbstractInterface::setSync(bool sync)
 {
+    setSync(sync, true);
 }
 
-void DDBusExtendedAbstractInterface::setSync(bool sync) { setSync(sync, true); }
-
 /*
- * Note: After sync is set to false, it will always return a empty value
+ * @~english
+ * @note After sync is set to false, it will always return a empty value
  * if you call the property's get function directly. So you can only get it
- * through the changed signal when you get an property, and it's also a good idea
- * to save a cache yourself.
- */
-
-/*
- * 注意: 如果设置 sync 为 false 那么在调用属性的 get 函数获取一个属性时会一直返回空值,
- * 解决方法是监听属性的 changed 信号并自行保存一份缓存, 让 changed 信号修改这个缓存
+ * through the changed signal when you get an property, and it's also a good
+ * idea to save a cache yourself.
  */
 void DDBusExtendedAbstractInterface::setSync(bool sync, bool autoStart)
 {
@@ -89,8 +93,7 @@ void DDBusExtendedAbstractInterface::getAllProperties()
 
         if (reply.signature() != QLatin1String("a{sv}")) {
             QString errorMessage = QStringLiteral("Invalid signature \"%1\" in return from call to %2")
-                .arg(reply.signature(),
-                     QString(*dBusPropertiesInterface()));
+                                       .arg(reply.signature(), QString(*dBusPropertiesInterface()));
             qWarning() << Q_FUNC_INFO << errorMessage;
             m_lastExtendedError = QDBusError(QDBusError::InvalidSignature, errorMessage);
             return;
@@ -102,22 +105,29 @@ void DDBusExtendedAbstractInterface::getAllProperties()
         QDBusPendingReply<QVariantMap> async = connection().asyncCall(msg);
         m_getAllPendingCallWatcher = new QDBusPendingCallWatcher(async, this);
 
-        connect(m_getAllPendingCallWatcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(onAsyncGetAllPropertiesFinished(QDBusPendingCallWatcher*)));
+        connect(m_getAllPendingCallWatcher,
+                SIGNAL(finished(QDBusPendingCallWatcher *)),
+                this,
+                SLOT(onAsyncGetAllPropertiesFinished(QDBusPendingCallWatcher *)));
         return;
     }
 }
 
 void DDBusExtendedAbstractInterface::connectNotify(const QMetaMethod &signal)
 {
-    if (signal.methodType() == QMetaMethod::Signal
-        && (signal.methodSignature() == *propertyChangedSignature()
-            || signal.methodSignature() == *propertyInvalidatedSignature())) {
+    if (signal.methodType() == QMetaMethod::Signal && (signal.methodSignature() == *propertyChangedSignature() ||
+                                                       signal.methodSignature() == *propertyInvalidatedSignature())) {
         if (!m_propertiesChangedConnected) {
             QStringList argumentMatch;
             argumentMatch << interface();
-            connection().connect(service(), path(), *dBusPropertiesInterface(), *dBusPropertiesChangedSignal(),
-                                 argumentMatch, QString(),
-                                 this, SLOT(onPropertiesChanged(QString, QVariantMap, QStringList)));
+            connection().connect(service(),
+                                 path(),
+                                 *dBusPropertiesInterface(),
+                                 *dBusPropertiesChangedSignal(),
+                                 argumentMatch,
+                                 QString(),
+                                 this,
+                                 SLOT(onPropertiesChanged(QString, QVariantMap, QStringList)));
 
             m_propertiesChangedConnected = true;
             return;
@@ -129,17 +139,20 @@ void DDBusExtendedAbstractInterface::connectNotify(const QMetaMethod &signal)
 
 void DDBusExtendedAbstractInterface::disconnectNotify(const QMetaMethod &signal)
 {
-    if (signal.methodType() == QMetaMethod::Signal
-        && (signal.methodSignature() == *propertyChangedSignature()
-            || signal.methodSignature() == *propertyInvalidatedSignature())) {
-        if (m_propertiesChangedConnected
-            && 0 == receivers(propertyChangedSignature()->constData())
-            && 0 == receivers(propertyInvalidatedSignature()->constData())) {
+    if (signal.methodType() == QMetaMethod::Signal && (signal.methodSignature() == *propertyChangedSignature() ||
+                                                       signal.methodSignature() == *propertyInvalidatedSignature())) {
+        if (m_propertiesChangedConnected && 0 == receivers(propertyChangedSignature()->constData()) &&
+            0 == receivers(propertyInvalidatedSignature()->constData())) {
             QStringList argumentMatch;
             argumentMatch << interface();
-            connection().disconnect(service(), path(), *dBusPropertiesInterface(), *dBusPropertiesChangedSignal(),
-                                 argumentMatch, QString(),
-                                 this, SLOT(onPropertiesChanged(QString, QVariantMap, QStringList)));
+            connection().disconnect(service(),
+                                    path(),
+                                    *dBusPropertiesInterface(),
+                                    *dBusPropertiesChangedSignal(),
+                                    argumentMatch,
+                                    QString(),
+                                    this,
+                                    SLOT(onPropertiesChanged(QString, QVariantMap, QStringList)));
 
             m_propertiesChangedConnected = false;
             return;
@@ -176,8 +189,7 @@ QVariant DDBusExtendedAbstractInterface::internalPropGet(const char *propname, v
         int propertyIndex = metaObject()->indexOfProperty(propname);
 
         if (-1 == propertyIndex) {
-            QString errorMessage = QStringLiteral("Got unknown property \"%1\" to read")
-                .arg(QString::fromLatin1(propname));
+            QString errorMessage = QStringLiteral("Got unknown property \"%1\" to read").arg(QString::fromLatin1(propname));
             m_lastExtendedError = QDBusMessage::createError(QDBusError::Failed, errorMessage);
             qWarning() << Q_FUNC_INFO << errorMessage;
             return QVariant();
@@ -186,8 +198,7 @@ QVariant DDBusExtendedAbstractInterface::internalPropGet(const char *propname, v
         QMetaProperty metaProperty = metaObject()->property(propertyIndex);
 
         if (!metaProperty.isReadable()) {
-            QString errorMessage = QStringLiteral("Property \"%1\" is NOT readable")
-                .arg(QString::fromLatin1(propname));
+            QString errorMessage = QStringLiteral("Property \"%1\" is NOT readable").arg(QString::fromLatin1(propname));
             m_lastExtendedError = QDBusMessage::createError(QDBusError::Failed, errorMessage);
             qWarning() << Q_FUNC_INFO << errorMessage;
             return QVariant();
@@ -198,13 +209,10 @@ QVariant DDBusExtendedAbstractInterface::internalPropGet(const char *propname, v
         if (int(metaProperty.type()) != QMetaType::QVariant) {
             expectedSignature = QDBusMetaType::typeToSignature(metaProperty.userType());
             if (0 == expectedSignature) {
-                QString errorMessage =
-                    QStringLiteral("Type %1 must be registered with Qt D-Bus "
-                                   "before it can be used to read property "
-                                   "%2.%3")
-                    .arg(metaProperty.typeName(),
-                         interface(),
-                         propname);
+                QString errorMessage = QStringLiteral("Type %1 must be registered with Qt D-Bus "
+                                                      "before it can be used to read property "
+                                                      "%2.%3")
+                                           .arg(metaProperty.typeName(), interface(), propname);
                 m_lastExtendedError = QDBusMessage::createError(QDBusError::Failed, errorMessage);
                 qWarning() << Q_FUNC_INFO << errorMessage;
                 return QVariant();
@@ -233,8 +241,7 @@ void DDBusExtendedAbstractInterface::internalPropSet(const char *propname, const
         int propertyIndex = metaObject()->indexOfProperty(propname);
 
         if (-1 == propertyIndex) {
-            QString errorMessage = QStringLiteral("Got unknown property \"%1\" to write")
-                .arg(QString::fromLatin1(propname));
+            QString errorMessage = QStringLiteral("Got unknown property \"%1\" to write").arg(QString::fromLatin1(propname));
             m_lastExtendedError = QDBusMessage::createError(QDBusError::Failed, errorMessage);
             qWarning() << Q_FUNC_INFO << errorMessage;
             return;
@@ -243,8 +250,7 @@ void DDBusExtendedAbstractInterface::internalPropSet(const char *propname, const
         QMetaProperty metaProperty = metaObject()->property(propertyIndex);
 
         if (!metaProperty.isWritable()) {
-            QString errorMessage = QStringLiteral("Property \"%1\" is NOT writable")
-                .arg(QString::fromLatin1(propname));
+            QString errorMessage = QStringLiteral("Property \"%1\" is NOT writable").arg(QString::fromLatin1(propname));
             m_lastExtendedError = QDBusMessage::createError(QDBusError::Failed, errorMessage);
             qWarning() << Q_FUNC_INFO << errorMessage;
             return;
@@ -264,7 +270,7 @@ QVariant DDBusExtendedAbstractInterface::asyncProperty(const QString &propertyNa
     QDBusPendingReply<QVariant> async = connection().asyncCall(msg);
     DDBusExtendedPendingCallWatcher *watcher = new DDBusExtendedPendingCallWatcher(async, propertyName, QVariant(), this);
 
-    connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(onAsyncPropertyFinished(QDBusPendingCallWatcher*)));
+    connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher *)), this, SLOT(onAsyncPropertyFinished(QDBusPendingCallWatcher *)));
 
     return QVariant();
 }
@@ -277,20 +283,21 @@ void DDBusExtendedAbstractInterface::asyncSetProperty(const QString &propertyNam
     QDBusPendingReply<> async = connection().asyncCall(msg);
     DDBusExtendedPendingCallWatcher *watcher = new DDBusExtendedPendingCallWatcher(async, propertyName, value, this);
 
-    connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(onAsyncSetPropertyFinished(QDBusPendingCallWatcher*)));
+    connect(
+        watcher, SIGNAL(finished(QDBusPendingCallWatcher *)), this, SLOT(onAsyncSetPropertyFinished(QDBusPendingCallWatcher *)));
 }
 
 void DDBusExtendedAbstractInterface::startServiceProcess()
 {
     const QString &servName = service();
 
-    if (isValid())
-    {
+    if (isValid()) {
         qWarning() << "Service" << servName << "is already started.";
         return;
     }
 
-    QDBusMessage msg = QDBusMessage::createMethodCall("org.freedesktop.DBus", "/", *dBusInterface(), QStringLiteral("StartServiceByName"));
+    QDBusMessage msg =
+        QDBusMessage::createMethodCall("org.freedesktop.DBus", "/", *dBusInterface(), QStringLiteral("StartServiceByName"));
     msg << servName << quint32(0);
     QDBusPendingReply<quint32> async = connection().asyncCall(msg);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(async, this);
@@ -300,8 +307,7 @@ void DDBusExtendedAbstractInterface::startServiceProcess()
 
 void DDBusExtendedAbstractInterface::onStartServiceProcessFinished(QDBusPendingCallWatcher *w)
 {
-    if (w->isError())
-    {
+    if (w->isError()) {
         m_lastExtendedError = w->error();
     } else {
         m_lastExtendedError = QDBusError();
@@ -325,10 +331,7 @@ void DDBusExtendedAbstractInterface::onAsyncPropertyFinished(QDBusPendingCallWat
         m_lastExtendedError = reply.error();
     } else {
         int propertyIndex = metaObject()->indexOfProperty(watcher->asyncProperty().toLatin1().constData());
-        QVariant value = demarshall(interface(),
-                                    metaObject()->property(propertyIndex),
-                                    reply.value(),
-                                    &m_lastExtendedError);
+        QVariant value = demarshall(interface(), metaObject()->property(propertyIndex), reply.value(), &m_lastExtendedError);
 
         if (m_lastExtendedError.isValid()) {
             Q_EMIT propertyInvalidated(watcher->asyncProperty());
@@ -387,9 +390,9 @@ void DDBusExtendedAbstractInterface::onAsyncGetAllPropertiesFinished(QDBusPendin
     watcher->deleteLater();
 }
 
-void DDBusExtendedAbstractInterface::onPropertiesChanged(const QString& interfaceName,
-                                                        const QVariantMap& changedProperties,
-                                                        const QStringList& invalidatedProperties)
+void DDBusExtendedAbstractInterface::onPropertiesChanged(const QString &interfaceName,
+                                                         const QVariantMap &changedProperties,
+                                                         const QStringList &invalidatedProperties)
 {
     if (interfaceName == interface()) {
         QVariantMap::const_iterator i = changedProperties.constBegin();
@@ -397,7 +400,7 @@ void DDBusExtendedAbstractInterface::onPropertiesChanged(const QString& interfac
             int propertyIndex = metaObject()->indexOfProperty(i.key().toLatin1().constData());
 
             if (-1 == propertyIndex) {
-                qDebug() << Q_FUNC_INFO << "Got unknown changed property" <<  i.key();
+                qDebug() << Q_FUNC_INFO << "Got unknown changed property" << i.key();
             } else {
                 QVariant value = demarshall(interface(), metaObject()->property(propertyIndex), i.value(), &m_lastExtendedError);
 
@@ -414,7 +417,7 @@ void DDBusExtendedAbstractInterface::onPropertiesChanged(const QString& interfac
         QStringList::const_iterator j = invalidatedProperties.constBegin();
         while (j != invalidatedProperties.constEnd()) {
             if (-1 == metaObject()->indexOfProperty(j->toLatin1().constData())) {
-                qDebug() << Q_FUNC_INFO << "Got unknown invalidated property" <<  *j;
+                qDebug() << Q_FUNC_INFO << "Got unknown invalidated property" << *j;
             } else {
                 m_lastExtendedError = QDBusError();
                 Q_EMIT propertyInvalidated(*j);
@@ -427,19 +430,19 @@ void DDBusExtendedAbstractInterface::onPropertiesChanged(const QString& interfac
 
 void DDBusExtendedAbstractInterface::onDBusNameOwnerChanged(const QString &name, const QString &oldOwner, const QString &newOwner)
 {
-    if (name == service() && oldOwner.isEmpty())
-    {
+    if (name == service() && oldOwner.isEmpty()) {
         m_dbusOwner = newOwner;
         Q_EMIT serviceValidChanged(true);
-    }
-    else if (name == m_dbusOwner && newOwner.isEmpty())
-    {
+    } else if (name == m_dbusOwner && newOwner.isEmpty()) {
         m_dbusOwner.clear();
         Q_EMIT serviceValidChanged(false);
     }
 }
 
-QVariant DDBusExtendedAbstractInterface::demarshall(const QString &interface, const QMetaProperty &metaProperty, const QVariant &value, QDBusError *error)
+QVariant DDBusExtendedAbstractInterface::demarshall(const QString &interface,
+                                                    const QMetaProperty &metaProperty,
+                                                    const QVariant &value,
+                                                    QDBusError *error)
 {
     Q_ASSERT(metaProperty.isValid());
     Q_ASSERT(error != 0);
@@ -450,7 +453,7 @@ QVariant DDBusExtendedAbstractInterface::demarshall(const QString &interface, co
         return value;
     }
 
-    QVariant result = QVariant(metaProperty.userType(), (void*)0);
+    QVariant result = QVariant(metaProperty.userType(), (void *)0);
     QString errorMessage;
     const char *expectedSignature = QDBusMetaType::typeToSignature(metaProperty.userType());
 
@@ -464,20 +467,20 @@ QVariant DDBusExtendedAbstractInterface::demarshall(const QString &interface, co
                 errorMessage = QStringLiteral("Unexpected failure demarshalling "
                                               "upon PropertiesChanged signal arrival "
                                               "for property `%3.%4' (expected type `%5' (%6))")
-                    .arg(interface,
-                         QString::fromLatin1(metaProperty.name()),
-                         QString::fromLatin1(metaProperty.typeName()),
-                         expectedSignature);
+                                   .arg(interface,
+                                        QString::fromLatin1(metaProperty.name()),
+                                        QString::fromLatin1(metaProperty.typeName()),
+                                        expectedSignature);
             }
         } else {
-                errorMessage = QStringLiteral("Unexpected `user type' (%2) "
-                                              "upon PropertiesChanged signal arrival "
-                                              "for property `%3.%4' (expected type `%5' (%6))")
-                    .arg(dbusArg.currentSignature(),
-                         interface,
-                         QString::fromLatin1(metaProperty.name()),
-                         QString::fromLatin1(metaProperty.typeName()),
-                         QString::fromLatin1(expectedSignature));
+            errorMessage = QStringLiteral("Unexpected `user type' (%2) "
+                                          "upon PropertiesChanged signal arrival "
+                                          "for property `%3.%4' (expected type `%5' (%6))")
+                               .arg(dbusArg.currentSignature(),
+                                    interface,
+                                    QString::fromLatin1(metaProperty.name()),
+                                    QString::fromLatin1(metaProperty.typeName()),
+                                    QString::fromLatin1(expectedSignature));
         }
     } else {
         const char *actualSignature = QDBusMetaType::typeToSignature(value.userType());
@@ -485,12 +488,12 @@ QVariant DDBusExtendedAbstractInterface::demarshall(const QString &interface, co
         errorMessage = QStringLiteral("Unexpected `%1' (%2) "
                                       "upon PropertiesChanged signal arrival "
                                       "for property `%3.%4' (expected type `%5' (%6))")
-            .arg(QString::fromLatin1(value.typeName()),
-                 QString::fromLatin1(actualSignature),
-                 interface,
-                 QString::fromLatin1(metaProperty.name()),
-                 QString::fromLatin1(metaProperty.typeName()),
-                 QString::fromLatin1(expectedSignature));
+                           .arg(QString::fromLatin1(value.typeName()),
+                                QString::fromLatin1(actualSignature),
+                                interface,
+                                QString::fromLatin1(metaProperty.name()),
+                                QString::fromLatin1(metaProperty.typeName()),
+                                QString::fromLatin1(expectedSignature));
     }
 
     if (errorMessage.isEmpty()) {
@@ -502,3 +505,4 @@ QVariant DDBusExtendedAbstractInterface::demarshall(const QString &interface, co
 
     return result;
 }
+DCORE_END_NAMESPACE
